# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf-8 -*-
#
# Copyright 2002 Ben Escoto <ben@emerose.org>
# Copyright 2007 Kenneth Loafman <kenneth@loafman.com>
# Copyright 2011 Canonical Ltd
#
# This file is part of duplicity.
#
# Duplicity is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# Duplicity is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with duplicity; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

from __future__ import print_function
from future import standard_library
standard_library.install_aliases()

import pytest
import unittest

from testing import _runtest_dir
from . import CmdError, FunctionalTestCase


class BadUploadTest(FunctionalTestCase):
    u"""
    Test missing volume upload using duplicity binary
    """
    @pytest.mark.slow
    def test_missing_file(self):
        u"""
        Test basic lost file
        """
        try:
            self.backup(u"full", u"{0}/testfiles/dir1".format(_runtest_dir), options=[u"--skip-volume=1"])
            self.fail()
        except CmdError as e:
            self.assertEqual(e.exit_status, 44, str(e))
        else:
            self.fail(u'Expected CmdError not thrown')


if __name__ == u"__main__":
    unittest.main()



# *******************************************************
# *** This is a generated file from project duplicity ***
# ***                 DO NOT MODIFY!                  ***
# *** Use tools/make_gpg_error_codes.py to update.    ***
# *******************************************************

gpg_error_codes = {
    0: u'GPG_ERR_NO_ERROR: ' + _(u'Success'),
    1: u'GPG_ERR_GENERAL: ' + _(u'General error'),
    2: u'GPG_ERR_UNKNOWN_PACKET: ' + _(u'Unknown packet'),
    3: u'GPG_ERR_UNKNOWN_VERSION: ' + _(u'Unknown version in packet'),
    4: u'GPG_ERR_PUBKEY_ALGO: ' + _(u'Invalid public key algorithm'),
    5: u'GPG_ERR_DIGEST_ALGO: ' + _(u'Invalid digest algorithm'),
    6: u'GPG_ERR_BAD_PUBKEY: ' + _(u'Bad public key'),
    7: u'GPG_ERR_BAD_SECKEY: ' + _(u'Bad secret key'),
    8: u'GPG_ERR_BAD_SIGNATURE: ' + _(u'Bad signature'),
    9: u'GPG_ERR_NO_PUBKEY: ' + _(u'No public key'),
    10: u'GPG_ERR_CHECKSUM: ' + _(u'Checksum error'),
    11: u'GPG_ERR_BAD_PASSPHRASE: ' + _(u'Bad passphrase'),
    12: u'GPG_ERR_CIPHER_ALGO: ' + _(u'Invalid cipher algorithm'),
    13: u'GPG_ERR_KEYRING_OPEN: ' + _(u'Cannot open keyring'),
    14: u'GPG_ERR_INV_PACKET: ' + _(u'Invalid packet'),
    15: u'GPG_ERR_INV_ARMOR: ' + _(u'Invalid armor'),
    16: u'GPG_ERR_NO_USER_ID: ' + _(u'No user ID'),
    17: u'GPG_ERR_NO_SECKEY: ' + _(u'No secret key'),
    18: u'GPG_ERR_WRONG_SECKEY: ' + _(u'Wrong secret key used'),
    19: u'GPG_ERR_BAD_KEY: ' + _(u'Bad session key'),
    20: u'GPG_ERR_COMPR_ALGO: ' + _(u'Unknown compression algorithm'),
    21: u'GPG_ERR_NO_PRIME: ' + _(u'Number is not prime'),
    22: u'GPG_ERR_NO_ENCODING_METHOD: ' + _(u'Invalid encoding method'),
    23: u'GPG_ERR_NO_ENCRYPTION_SCHEME: ' + _(u'Invalid encryption scheme'),
    24: u'GPG_ERR_NO_SIGNATURE_SCHEME: ' + _(u'Invalid signature scheme'),
    25: u'GPG_ERR_INV_ATTR: ' + _(u'Invalid attribute'),
    26: u'GPG_ERR_NO_VALUE: ' + _(u'No value'),
    27: u'GPG_ERR_NOT_FOUND: ' + _(u'Not found'),
    28: u'GPG_ERR_VALUE_NOT_FOUND: ' + _(u'Value not found'),
    29: u'GPG_ERR_SYNTAX: ' + _(u'Syntax error'),
    30: u'GPG_ERR_BAD_MPI: ' + _(u'Bad MPI value'),
    31: u'GPG_ERR_INV_PASSPHRASE: ' + _(u'Invalid passphrase'),
    32: u'GPG_ERR_SIG_CLASS: ' + _(u'Invalid signature class'),
    33: u'GPG_ERR_RESOURCE_LIMIT: ' + _(u'Resources exhausted'),
    34: u'GPG_ERR_INV_KEYRING: ' + _(u'Invalid keyring'),
    35: u'GPG_ERR_TRUSTDB: ' + _(u'Trust DB error'),
    36: u'GPG_ERR_BAD_CERT: ' + _(u'Bad certificate'),
    37: u'GPG_ERR_INV_USER_ID: ' + _(u'Invalid user ID'),
    38: u'GPG_ERR_UNEXPECTED: ' + _(u'Unexpected error'),
    39: u'GPG_ERR_TIME_CONFLICT: ' + _(u'Time conflict'),
    40: u'GPG_ERR_KEYSERVER: ' + _(u'Keyserver error'),
    41: u'GPG_ERR_WRONG_PUBKEY_ALGO: ' + _(u'Wrong public key algorithm'),
    42: u'GPG_ERR_TRIBUTE_TO_D_A: ' + _(u'Tribute to D. A.'),
    43: u'GPG_ERR_WEAK_KEY: ' + _(u'Weak encryption key'),
    44: u'GPG_ERR_INV_KEYLEN: ' + _(u'Invalid key length'),
    45: u'GPG_ERR_INV_ARG: ' + _(u'Invalid argument'),
    46: u'GPG_ERR_BAD_URI: ' + _(u'Syntax error in URI'),
    47: u'GPG_ERR_INV_URI: ' + _(u'Invalid URI'),
    48: u'GPG_ERR_NETWORK: ' + _(u'Network error'),
    49: u'GPG_ERR_UNKNOWN_HOST: ' + _(u'Unknown host'),
    50: u'GPG_ERR_SELFTEST_FAILED: ' + _(u'Selftest failed'),
    51: u'GPG_ERR_NOT_ENCRYPTED: ' + _(u'Data not encrypted'),
    52: u'GPG_ERR_NOT_PROCESSED: ' + _(u'Data not processed'),
    53: u'GPG_ERR_UNUSABLE_PUBKEY: ' + _(u'Unusable public key'),
    54: u'GPG_ERR_UNUSABLE_SECKEY: ' + _(u'Unusable secret key'),
    55: u'GPG_ERR_INV_VALUE: ' + _(u'Invalid value'),
    56: u'GPG_ERR_BAD_CERT_CHAIN: ' + _(u'Bad certificate chain'),
    57: u'GPG_ERR_MISSING_CERT: ' + _(u'Missing certificate'),
    58: u'GPG_ERR_NO_DATA: ' + _(u'No data'),
    59: u'GPG_ERR_BUG: ' + _(u'Bug'),
    60: u'GPG_ERR_NOT_SUPPORTED: ' + _(u'Not supported'),
    61: u'GPG_ERR_INV_OP: ' + _(u'Invalid operation code'),
    62: u'GPG_ERR_TIMEOUT: ' + _(u'Timeout'),
    63: u'GPG_ERR_INTERNAL: ' + _(u'Internal error'),
    64: u'GPG_ERR_EOF_GCRYPT: ' + _(u'EOF (gcrypt)'),
    65: u'GPG_ERR_INV_OBJ: ' + _(u'Invalid object'),
    66: u'GPG_ERR_TOO_SHORT: ' + _(u'Provided object is too short'),
    67: u'GPG_ERR_TOO_LARGE: ' + _(u'Provided object is too large'),
    68: u'GPG_ERR_NO_OBJ: ' + _(u'Missing item in object'),
    69: u'GPG_ERR_NOT_IMPLEMENTED: ' + _(u'Not implemented'),
    70: u'GPG_ERR_CONFLICT: ' + _(u'Conflicting use'),
    71: u'GPG_ERR_INV_CIPHER_MODE: ' + _(u'Invalid cipher mode'),
    72: u'GPG_ERR_INV_FLAG: ' + _(u'Invalid flag'),
    73: u'GPG_ERR_INV_HANDLE: ' + _(u'Invalid handle'),
    74: u'GPG_ERR_TRUNCATED: ' + _(u'Result truncated'),
    75: u'GPG_ERR_INCOMPLETE_LINE: ' + _(u'Incomplete line'),
    76: u'GPG_ERR_INV_RESPONSE: ' + _(u'Invalid response'),
    77: u'GPG_ERR_NO_AGENT: ' + _(u'No agent running'),
    78: u'GPG_ERR_AGENT: ' + _(u'Agent error'),
    79: u'GPG_ERR_INV_DATA: ' + _(u'Invalid data'),
    80: u'GPG_ERR_ASSUAN_SERVER_FAULT: ' + _(u'Unspecific Assuan server fault'),
    81: u'GPG_ERR_ASSUAN: ' + _(u'General Assuan error'),
    82: u'GPG_ERR_INV_SESSION_KEY: ' + _(u'Invalid session key'),
    83: u'GPG_ERR_INV_SEXP: ' + _(u'Invalid S-expression'),
    84: u'GPG_ERR_UNSUPPORTED_ALGORITHM: ' + _(u'Unsupported algorithm'),
    85: u'GPG_ERR_NO_PIN_ENTRY: ' + _(u'No pinentry'),
    86: u'GPG_ERR_PIN_ENTRY: ' + _(u'pinentry error'),
    87: u'GPG_ERR_BAD_PIN: ' + _(u'Bad PIN'),
    88: u'GPG_ERR_INV_NAME: ' + _(u'Invalid name'),
    89: u'GPG_ERR_BAD_DATA: ' + _(u'Bad data'),
    90: u'GPG_ERR_INV_PARAMETER: ' + _(u'Invalid parameter'),
    91: u'GPG_ERR_WRONG_CARD: ' + _(u'Wrong card'),
    92: u'GPG_ERR_NO_DIRMNGR: ' + _(u'No dirmngr'),
    93: u'GPG_ERR_DIRMNGR: ' + _(u'dirmngr error'),
    94: u'GPG_ERR_CERT_REVOKED: ' + _(u'Certificate revoked'),
    95: u'GPG_ERR_NO_CRL_KNOWN: ' + _(u'No CRL known'),
    96: u'GPG_ERR_CRL_TOO_OLD: ' + _(u'CRL too old'),
    97: u'GPG_ERR_LINE_TOO_LONG: ' + _(u'Line too long'),
    98: u'GPG_ERR_NOT_TRUSTED: ' + _(u'Not trusted'),
    99: u'GPG_ERR_CANCELED: ' + _(u'Operation cancelled'),
    100: u'GPG_ERR_BAD_CA_CERT: ' + _(u'Bad CA certificate'),
    101: u'GPG_ERR_CERT_EXPIRED: ' + _(u'Certificate expired'),
    102: u'GPG_ERR_CERT_TOO_YOUNG: ' + _(u'Certificate too young'),
    103: u'GPG_ERR_UNSUPPORTED_CERT: ' + _(u'Unsupported certificate'),
    104: u'GPG_ERR_UNKNOWN_SEXP: ' + _(u'Unknown S-expression'),
    105: u'GPG_ERR_UNSUPPORTED_PROTECTION: ' + _(u'Unsupported protection'),
    106: u'GPG_ERR_CORRUPTED_PROTECTION: ' + _(u'Corrupted protection'),
    107: u'GPG_ERR_AMBIGUOUS_NAME: ' + _(u'Ambiguous name'),
    108: u'GPG_ERR_CARD: ' + _(u'Card error'),
    109: u'GPG_ERR_CARD_RESET: ' + _(u'Card reset required'),
    110: u'GPG_ERR_CARD_REMOVED: ' + _(u'Card removed'),
    111: u'GPG_ERR_INV_CARD: ' + _(u'Invalid card'),
    112: u'GPG_ERR_CARD_NOT_PRESENT: ' + _(u'Card not present'),
    114: u'GPG_ERR_NOT_CONFIRMED: ' + _(u'Not confirmed'),
    115: u'GPG_ERR_CONFIGURATION: ' + _(u'Configuration error'),
    116: u'GPG_ERR_NO_POLICY_MATCH: ' + _(u'No policy match'),
    117: u'GPG_ERR_INV_INDEX: ' + _(u'Invalid index'),
    118: u'GPG_ERR_INV_ID: ' + _(u'Invalid ID'),
    119: u'GPG_ERR_NO_SCDAEMON: ' + _(u'No SmartCard daemon'),
    120: u'GPG_ERR_SCDAEMON: ' + _(u'SmartCard daemon error'),
    121: u'GPG_ERR_UNSUPPORTED_PROTOCOL: ' + _(u'Unsupported protocol'),
    122: u'GPG_ERR_BAD_PIN_METHOD: ' + _(u'Bad PIN method'),
    123: u'GPG_ERR_CARD_NOT_INITIALIZED: ' + _(u'Card not initialized'),
    124: u'GPG_ERR_UNSUPPORTED_OPERATION: ' + _(u'Unsupported operation'),
    125: u'GPG_ERR_WRONG_KEY_USAGE: ' + _(u'Wrong key usage'),
    126: u'GPG_ERR_NOTHING_FOUND: ' + _(u'Nothing found'),
    127: u'GPG_ERR_WRONG_BLOB_TYPE: ' + _(u'Wrong blob type'),
    128: u'GPG_ERR_MISSING_VALUE: ' + _(u'Missing value'),
    129: u'GPG_ERR_HARDWARE: ' + _(u'Hardware problem'),
    130: u'GPG_ERR_PIN_BLOCKED: ' + _(u'PIN blocked'),
    131: u'GPG_ERR_USE_CONDITIONS: ' + _(u'Conditions of use not satisfied'),
    132: u'GPG_ERR_PIN_NOT_SYNCED: ' + _(u'PINs are not synced'),
    133: u'GPG_ERR_INV_CRL: ' + _(u'Invalid CRL'),
    134: u'GPG_ERR_BAD_BER: ' + _(u'BER error'),
    135: u'GPG_ERR_INV_BER: ' + _(u'Invalid BER'),
    136: u'GPG_ERR_ELEMENT_NOT_FOUND: ' + _(u'Element not found'),
    137: u'GPG_ERR_IDENTIFIER_NOT_FOUND: ' + _(u'Identifier not found'),
    138: u'GPG_ERR_INV_TAG: ' + _(u'Invalid tag'),
    139: u'GPG_ERR_INV_LENGTH: ' + _(u'Invalid length'),
    140: u'GPG_ERR_INV_KEYINFO: ' + _(u'Invalid key info'),
    141: u'GPG_ERR_UNEXPECTED_TAG: ' + _(u'Unexpected tag'),
    142: u'GPG_ERR_NOT_DER_ENCODED: ' + _(u'Not DER encoded'),
    143: u'GPG_ERR_NO_CMS_OBJ: ' + _(u'No CMS object'),
    144: u'GPG_ERR_INV_CMS_OBJ: ' + _(u'Invalid CMS object'),
    145: u'GPG_ERR_UNKNOWN_CMS_OBJ: ' + _(u'Unknown CMS object'),
    146: u'GPG_ERR_UNSUPPORTED_CMS_OBJ: ' + _(u'Unsupported CMS object'),
    147: u'GPG_ERR_UNSUPPORTED_ENCODING: ' + _(u'Unsupported encoding'),
    148: u'GPG_ERR_UNSUPPORTED_CMS_VERSION: ' + _(u'Unsupported CMS version'),
    149: u'GPG_ERR_UNKNOWN_ALGORITHM: ' + _(u'Unknown algorithm'),
    150: u'GPG_ERR_INV_ENGINE: ' + _(u'Invalid crypto engine'),
    151: u'GPG_ERR_PUBKEY_NOT_TRUSTED: ' + _(u'Public key not trusted'),
    152: u'GPG_ERR_DECRYPT_FAILED: ' + _(u'Decryption failed'),
    153: u'GPG_ERR_KEY_EXPIRED: ' + _(u'Key expired'),
    154: u'GPG_ERR_SIG_EXPIRED: ' + _(u'Signature expired'),
    155: u'GPG_ERR_ENCODING_PROBLEM: ' + _(u'Encoding problem'),
    156: u'GPG_ERR_INV_STATE: ' + _(u'Invalid state'),
    157: u'GPG_ERR_DUP_VALUE: ' + _(u'Duplicated value'),
    158: u'GPG_ERR_MISSING_ACTION: ' + _(u'Missing action'),
    159: u'GPG_ERR_MODULE_NOT_FOUND: ' + _(u'ASN.1 module not found'),
    160: u'GPG_ERR_INV_OID_STRING: ' + _(u'Invalid OID string'),
    161: u'GPG_ERR_INV_TIME: ' + _(u'Invalid time'),
    162: u'GPG_ERR_INV_CRL_OBJ: ' + _(u'Invalid CRL object'),
    163: u'GPG_ERR_UNSUPPORTED_CRL_VERSION: ' + _(u'Unsupported CRL version'),
    164: u'GPG_ERR_INV_CERT_OBJ: ' + _(u'Invalid certificate object'),
    165: u'GPG_ERR_UNKNOWN_NAME: ' + _(u'Unknown name'),
    166: u'GPG_ERR_LOCALE_PROBLEM: ' + _(u'A locale function failed'),
    167: u'GPG_ERR_NOT_LOCKED: ' + _(u'Not locked'),
    168: u'GPG_ERR_PROTOCOL_VIOLATION: ' + _(u'Protocol violation'),
    169: u'GPG_ERR_INV_MAC: ' + _(u'Invalid MAC'),
    170: u'GPG_ERR_INV_REQUEST: ' + _(u'Invalid request'),
    171: u'GPG_ERR_UNKNOWN_EXTN: ' + _(u'Unknown extension'),
    172: u'GPG_ERR_UNKNOWN_CRIT_EXTN: ' + _(u'Unknown critical extension'),
    173: u'GPG_ERR_LOCKED: ' + _(u'Locked'),
    174: u'GPG_ERR_UNKNOWN_OPTION: ' + _(u'Unknown option'),
    175: u'GPG_ERR_UNKNOWN_COMMAND: ' + _(u'Unknown command'),
    176: u'GPG_ERR_NOT_OPERATIONAL: ' + _(u'Not operational'),
    177: u'GPG_ERR_NO_PASSPHRASE: ' + _(u'No passphrase given'),
    178: u'GPG_ERR_NO_PIN: ' + _(u'No PIN given'),
    179: u'GPG_ERR_NOT_ENABLED: ' + _(u'Not enabled'),
    180: u'GPG_ERR_NO_ENGINE: ' + _(u'No crypto engine'),
    181: u'GPG_ERR_MISSING_KEY: ' + _(u'Missing key'),
    182: u'GPG_ERR_TOO_MANY: ' + _(u'Too many objects'),
    183: u'GPG_ERR_LIMIT_REACHED: ' + _(u'Limit reached'),
    184: u'GPG_ERR_NOT_INITIALIZED: ' + _(u'Not initialized'),
    185: u'GPG_ERR_MISSING_ISSUER_CERT: ' + _(u'Missing issuer certificate'),
    186: u'GPG_ERR_NO_KEYSERVER: ' + _(u'No keyserver available'),
    187: u'GPG_ERR_INV_CURVE: ' + _(u'Invalid elliptic curve'),
    188: u'GPG_ERR_UNKNOWN_CURVE: ' + _(u'Unknown elliptic curve'),
    189: u'GPG_ERR_DUP_KEY: ' + _(u'Duplicated key'),
    190: u'GPG_ERR_AMBIGUOUS: ' + _(u'Ambiguous result'),
    191: u'GPG_ERR_NO_CRYPT_CTX: ' + _(u'No crypto context'),
    192: u'GPG_ERR_WRONG_CRYPT_CTX: ' + _(u'Wrong crypto context'),
    193: u'GPG_ERR_BAD_CRYPT_CTX: ' + _(u'Bad crypto context'),
    194: u'GPG_ERR_CRYPT_CTX_CONFLICT: ' + _(u'Conflict in the crypto context'),
    195: u'GPG_ERR_BROKEN_PUBKEY: ' + _(u'Broken public key'),
    196: u'GPG_ERR_BROKEN_SECKEY: ' + _(u'Broken secret key'),
    197: u'GPG_ERR_MAC_ALGO: ' + _(u'Invalid MAC algorithm'),
    198: u'GPG_ERR_FULLY_CANCELED: ' + _(u'Operation fully cancelled'),
    199: u'GPG_ERR_UNFINISHED: ' + _(u'Operation not yet finished'),
    200: u'GPG_ERR_BUFFER_TOO_SHORT: ' + _(u'Buffer too short'),
    201: u'GPG_ERR_SEXP_INV_LEN_SPEC: ' + _(u'Invalid length specifier in S-expression'),
    202: u'GPG_ERR_SEXP_STRING_TOO_LONG: ' + _(u'String too long in S-expression'),
    203: u'GPG_ERR_SEXP_UNMATCHED_PAREN: ' + _(u'Unmatched parentheses in S-expression'),
    204: u'GPG_ERR_SEXP_NOT_CANONICAL: ' + _(u'S-expression not canonical'),
    205: u'GPG_ERR_SEXP_BAD_CHARACTER: ' + _(u'Bad character in S-expression'),
    206: u'GPG_ERR_SEXP_BAD_QUOTATION: ' + _(u'Bad quotation in S-expression'),
    207: u'GPG_ERR_SEXP_ZERO_PREFIX: ' + _(u'Zero prefix in S-expression'),
    208: u'GPG_ERR_SEXP_NESTED_DH: ' + _(u'Nested display hints in S-expression'),
    209: u'GPG_ERR_SEXP_UNMATCHED_DH: ' + _(u'Unmatched display hints'),
    210: u'GPG_ERR_SEXP_UNEXPECTED_PUNC: ' + _(u'Unexpected reserved punctuation in S-expression'),
    211: u'GPG_ERR_SEXP_BAD_HEX_CHAR: ' + _(u'Bad hexadecimal character in S-expression'),
    212: u'GPG_ERR_SEXP_ODD_HEX_NUMBERS: ' + _(u'Odd hexadecimal numbers in S-expression'),
    213: u'GPG_ERR_SEXP_BAD_OCT_CHAR: ' + _(u'Bad octal character in S-expression'),
    217: u'GPG_ERR_SUBKEYS_EXP_OR_REV: ' + _(u'All subkeys are expired or revoked'),
    218: u'GPG_ERR_DB_CORRUPTED: ' + _(u'Database is corrupted'),
    219: u'GPG_ERR_SERVER_FAILED: ' + _(u'Server indicated a failure'),
    220: u'GPG_ERR_NO_NAME: ' + _(u'No name'),
    221: u'GPG_ERR_NO_KEY: ' + _(u'No key'),
    222: u'GPG_ERR_LEGACY_KEY: ' + _(u'Legacy key'),
    223: u'GPG_ERR_REQUEST_TOO_SHORT: ' + _(u'Request too short'),
    224: u'GPG_ERR_REQUEST_TOO_LONG: ' + _(u'Request too long'),
    225: u'GPG_ERR_OBJ_TERM_STATE: ' + _(u'Object is in termination state'),
    226: u'GPG_ERR_NO_CERT_CHAIN: ' + _(u'No certificate chain'),
    227: u'GPG_ERR_CERT_TOO_LARGE: ' + _(u'Certificate is too large'),
    228: u'GPG_ERR_INV_RECORD: ' + _(u'Invalid record'),
    229: u'GPG_ERR_BAD_MAC: ' + _(u'The MAC does not verify'),
    230: u'GPG_ERR_UNEXPECTED_MSG: ' + _(u'Unexpected message'),
    231: u'GPG_ERR_COMPR_FAILED: ' + _(u'Compression or decompression failed'),
    232: u'GPG_ERR_WOULD_WRAP: ' + _(u'A counter would wrap'),
    233: u'GPG_ERR_FATAL_ALERT: ' + _(u'Fatal alert message received'),
    234: u'GPG_ERR_NO_CIPHER: ' + _(u'No cipher algorithm'),
    235: u'GPG_ERR_MISSING_CLIENT_CERT: ' + _(u'Missing client certificate'),
    236: u'GPG_ERR_CLOSE_NOTIFY: ' + _(u'Close notification received'),
    237: u'GPG_ERR_TICKET_EXPIRED: ' + _(u'Ticket expired'),
    238: u'GPG_ERR_BAD_TICKET: ' + _(u'Bad ticket'),
    239: u'GPG_ERR_UNKNOWN_IDENTITY: ' + _(u'Unknown identity'),
    240: u'GPG_ERR_BAD_HS_CERT: ' + _(u'Bad certificate message in handshake'),
    241: u'GPG_ERR_BAD_HS_CERT_REQ: ' + _(u'Bad certificate request message in handshake'),
    242: u'GPG_ERR_BAD_HS_CERT_VER: ' + _(u'Bad certificate verify message in handshake'),
    243: u'GPG_ERR_BAD_HS_CHANGE_CIPHER: ' + _(u'Bad change cipher message in handshake'),
    244: u'GPG_ERR_BAD_HS_CLIENT_HELLO: ' + _(u'Bad client hello message in handshake'),
    245: u'GPG_ERR_BAD_HS_SERVER_HELLO: ' + _(u'Bad server hello message in handshake'),
    246: u'GPG_ERR_BAD_HS_SERVER_HELLO_DONE: ' + _(u'Bad server hello done message in handshake'),
    247: u'GPG_ERR_BAD_HS_FINISHED: ' + _(u'Bad finished message in handshake'),
    248: u'GPG_ERR_BAD_HS_SERVER_KEX: ' + _(u'Bad server key exchange message in handshake'),
    249: u'GPG_ERR_BAD_HS_CLIENT_KEX: ' + _(u'Bad client key exchange message in handshake'),
    250: u'GPG_ERR_BOGUS_STRING: ' + _(u'Bogus string'),
    251: u'GPG_ERR_FORBIDDEN: ' + _(u'Forbidden'),
    252: u'GPG_ERR_KEY_DISABLED: ' + _(u'Key disabled'),
    253: u'GPG_ERR_KEY_ON_CARD: ' + _(u'Not possible with a card based key'),
    254: u'GPG_ERR_INV_LOCK_OBJ: ' + _(u'Invalid lock object'),
    255: u'GPG_ERR_TRUE: ' + _(u'True'),
    256: u'GPG_ERR_FALSE: ' + _(u'False'),
    257: u'GPG_ERR_ASS_GENERAL: ' + _(u'General IPC error'),
    258: u'GPG_ERR_ASS_ACCEPT_FAILED: ' + _(u'IPC accept call failed'),
    259: u'GPG_ERR_ASS_CONNECT_FAILED: ' + _(u'IPC connect call failed'),
    260: u'GPG_ERR_ASS_INV_RESPONSE: ' + _(u'Invalid IPC response'),
    261: u'GPG_ERR_ASS_INV_VALUE: ' + _(u'Invalid value passed to IPC'),
    262: u'GPG_ERR_ASS_INCOMPLETE_LINE: ' + _(u'Incomplete line passed to IPC'),
    263: u'GPG_ERR_ASS_LINE_TOO_LONG: ' + _(u'Line passed to IPC too long'),
    264: u'GPG_ERR_ASS_NESTED_COMMANDS: ' + _(u'Nested IPC commands'),
    265: u'GPG_ERR_ASS_NO_DATA_CB: ' + _(u'No data callback in IPC'),
    266: u'GPG_ERR_ASS_NO_INQUIRE_CB: ' + _(u'No inquire callback in IPC'),
    267: u'GPG_ERR_ASS_NOT_A_SERVER: ' + _(u'Not an IPC server'),
    268: u'GPG_ERR_ASS_NOT_A_CLIENT: ' + _(u'Not an IPC client'),
    269: u'GPG_ERR_ASS_SERVER_START: ' + _(u'Problem starting IPC server'),
    270: u'GPG_ERR_ASS_READ_ERROR: ' + _(u'IPC read error'),
    271: u'GPG_ERR_ASS_WRITE_ERROR: ' + _(u'IPC write error'),
    273: u'GPG_ERR_ASS_TOO_MUCH_DATA: ' + _(u'Too much data for IPC layer'),
    274: u'GPG_ERR_ASS_UNEXPECTED_CMD: ' + _(u'Unexpected IPC command'),
    275: u'GPG_ERR_ASS_UNKNOWN_CMD: ' + _(u'Unknown IPC command'),
    276: u'GPG_ERR_ASS_SYNTAX: ' + _(u'IPC syntax error'),
    277: u'GPG_ERR_ASS_CANCELED: ' + _(u'IPC call has been cancelled'),
    278: u'GPG_ERR_ASS_NO_INPUT: ' + _(u'No input source for IPC'),
    279: u'GPG_ERR_ASS_NO_OUTPUT: ' + _(u'No output source for IPC'),
    280: u'GPG_ERR_ASS_PARAMETER: ' + _(u'IPC parameter error'),
    281: u'GPG_ERR_ASS_UNKNOWN_INQUIRE: ' + _(u'Unknown IPC inquire'),
    300: u'GPG_ERR_ENGINE_TOO_OLD: ' + _(u'Crypto engine too old'),
    301: u'GPG_ERR_WINDOW_TOO_SMALL: ' + _(u'Screen or window too small'),
    302: u'GPG_ERR_WINDOW_TOO_LARGE: ' + _(u'Screen or window too large'),
    303: u'GPG_ERR_MISSING_ENVVAR: ' + _(u'Required environment variable not set'),
    304: u'GPG_ERR_USER_ID_EXISTS: ' + _(u'User ID already exists'),
    305: u'GPG_ERR_NAME_EXISTS: ' + _(u'Name already exists'),
    306: u'GPG_ERR_DUP_NAME: ' + _(u'Duplicated name'),
    307: u'GPG_ERR_TOO_YOUNG: ' + _(u'Object is too young'),
    308: u'GPG_ERR_TOO_OLD: ' + _(u'Object is too old'),
    309: u'GPG_ERR_UNKNOWN_FLAG: ' + _(u'Unknown flag'),
    310: u'GPG_ERR_INV_ORDER: ' + _(u'Invalid execution order'),
    311: u'GPG_ERR_ALREADY_FETCHED: ' + _(u'Already fetched'),
    312: u'GPG_ERR_TRY_LATER: ' + _(u'Try again later'),
    313: u'GPG_ERR_WRONG_NAME: ' + _(u'Wrong name'),
    314: u'GPG_ERR_NO_AUTH: ' + _(u'Not authenticated'),
    315: u'GPG_ERR_BAD_AUTH: ' + _(u'Bad authentication'),
    316: u'GPG_ERR_NO_KEYBOXD: ' + _(u'No Keybox daemon running'),
    317: u'GPG_ERR_KEYBOXD: ' + _(u'Keybox daemon error'),
    318: u'GPG_ERR_NO_SERVICE: ' + _(u'Service is not running'),
    319: u'GPG_ERR_SERVICE: ' + _(u'Service error'),
    666: u'GPG_ERR_SYSTEM_BUG: ' + _(u'System bug detected'),
    711: u'GPG_ERR_DNS_UNKNOWN: ' + _(u'Unknown DNS error'),
    712: u'GPG_ERR_DNS_SECTION: ' + _(u'Invalid DNS section'),
    713: u'GPG_ERR_DNS_ADDRESS: ' + _(u'Invalid textual address form'),
    714: u'GPG_ERR_DNS_NO_QUERY: ' + _(u'Missing DNS query packet'),
    715: u'GPG_ERR_DNS_NO_ANSWER: ' + _(u'Missing DNS answer packet'),
    716: u'GPG_ERR_DNS_CLOSED: ' + _(u'Connection closed in DNS'),
    717: u'GPG_ERR_DNS_VERIFY: ' + _(u'Verification failed in DNS'),
    718: u'GPG_ERR_DNS_TIMEOUT: ' + _(u'DNS Timeout'),
    721: u'GPG_ERR_LDAP_GENERAL: ' + _(u'General LDAP error'),
    722: u'GPG_ERR_LDAP_ATTR_GENERAL: ' + _(u'General LDAP attribute error'),
    723: u'GPG_ERR_LDAP_NAME_GENERAL: ' + _(u'General LDAP name error'),
    724: u'GPG_ERR_LDAP_SECURITY_GENERAL: ' + _(u'General LDAP security error'),
    725: u'GPG_ERR_LDAP_SERVICE_GENERAL: ' + _(u'General LDAP service error'),
    726: u'GPG_ERR_LDAP_UPDATE_GENERAL: ' + _(u'General LDAP update error'),
    727: u'GPG_ERR_LDAP_E_GENERAL: ' + _(u'Experimental LDAP error code'),
    728: u'GPG_ERR_LDAP_X_GENERAL: ' + _(u'Private LDAP error code'),
    729: u'GPG_ERR_LDAP_OTHER_GENERAL: ' + _(u'Other general LDAP error'),
    750: u'GPG_ERR_LDAP_X_CONNECTING: ' + _(u'LDAP connecting failed (X)'),
    751: u'GPG_ERR_LDAP_REFERRAL_LIMIT: ' + _(u'LDAP referral limit exceeded'),
    752: u'GPG_ERR_LDAP_CLIENT_LOOP: ' + _(u'LDAP client loop'),
    754: u'GPG_ERR_LDAP_NO_RESULTS: ' + _(u'No LDAP results returned'),
    755: u'GPG_ERR_LDAP_CONTROL_NOT_FOUND: ' + _(u'LDAP control not found'),
    756: u'GPG_ERR_LDAP_NOT_SUPPORTED: ' + _(u'Not supported by LDAP'),
    757: u'GPG_ERR_LDAP_CONNECT: ' + _(u'LDAP connect error'),
    758: u'GPG_ERR_LDAP_NO_MEMORY: ' + _(u'Out of memory in LDAP'),
    759: u'GPG_ERR_LDAP_PARAM: ' + _(u'Bad parameter to an LDAP routine'),
    760: u'GPG_ERR_LDAP_USER_CANCELLED: ' + _(u'User cancelled LDAP operation'),
    761: u'GPG_ERR_LDAP_FILTER: ' + _(u'Bad LDAP search filter'),
    762: u'GPG_ERR_LDAP_AUTH_UNKNOWN: ' + _(u'Unknown LDAP authentication method'),
    763: u'GPG_ERR_LDAP_TIMEOUT: ' + _(u'Timeout in LDAP'),
    764: u'GPG_ERR_LDAP_DECODING: ' + _(u'LDAP decoding error'),
    765: u'GPG_ERR_LDAP_ENCODING: ' + _(u'LDAP encoding error'),
    766: u'GPG_ERR_LDAP_LOCAL: ' + _(u'LDAP local error'),
    767: u'GPG_ERR_LDAP_SERVER_DOWN: ' + _(u'Cannot contact LDAP server'),
    768: u'GPG_ERR_LDAP_SUCCESS: ' + _(u'LDAP success'),
    769: u'GPG_ERR_LDAP_OPERATIONS: ' + _(u'LDAP operations error'),
    770: u'GPG_ERR_LDAP_PROTOCOL: ' + _(u'LDAP protocol error'),
    771: u'GPG_ERR_LDAP_TIMELIMIT: ' + _(u'Time limit exceeded in LDAP'),
    772: u'GPG_ERR_LDAP_SIZELIMIT: ' + _(u'Size limit exceeded in LDAP'),
    773: u'GPG_ERR_LDAP_COMPARE_FALSE: ' + _(u'LDAP compare false'),
    774: u'GPG_ERR_LDAP_COMPARE_TRUE: ' + _(u'LDAP compare true'),
    775: u'GPG_ERR_LDAP_UNSUPPORTED_AUTH: ' + _(u'LDAP authentication method not supported'),
    776: u'GPG_ERR_LDAP_STRONG_AUTH_RQRD: ' + _(u'Strong(er) LDAP authentication required'),
    777: u'GPG_ERR_LDAP_PARTIAL_RESULTS: ' + _(u'Partial LDAP results+referral received'),
    778: u'GPG_ERR_LDAP_REFERRAL: ' + _(u'LDAP referral'),
    779: u'GPG_ERR_LDAP_ADMINLIMIT: ' + _(u'Administrative LDAP limit exceeded'),
    780: u'GPG_ERR_LDAP_UNAVAIL_CRIT_EXTN: ' + _(u'Critical LDAP extension is unavailable'),
    781: u'GPG_ERR_LDAP_CONFIDENT_RQRD: ' + _(u'Confidentiality required by LDAP'),
    782: u'GPG_ERR_LDAP_SASL_BIND_INPROG: ' + _(u'LDAP SASL bind in progress'),
    784: u'GPG_ERR_LDAP_NO_SUCH_ATTRIBUTE: ' + _(u'No such LDAP attribute'),
    785: u'GPG_ERR_LDAP_UNDEFINED_TYPE: ' + _(u'Undefined LDAP attribute type'),
    786: u'GPG_ERR_LDAP_BAD_MATCHING: ' + _(u'Inappropriate matching in LDAP'),
    787: u'GPG_ERR_LDAP_CONST_VIOLATION: ' + _(u'Constraint violation in LDAP'),
    788: u'GPG_ERR_LDAP_TYPE_VALUE_EXISTS: ' + _(u'LDAP type or value exists'),
    789: u'GPG_ERR_LDAP_INV_SYNTAX: ' + _(u'Invalid syntax in LDAP'),
    800: u'GPG_ERR_LDAP_NO_SUCH_OBJ: ' + _(u'No such LDAP object'),
    801: u'GPG_ERR_LDAP_ALIAS_PROBLEM: ' + _(u'LDAP alias problem'),
    802: u'GPG_ERR_LDAP_INV_DN_SYNTAX: ' + _(u'Invalid DN syntax in LDAP'),
    803: u'GPG_ERR_LDAP_IS_LEAF: ' + _(u'LDAP entry is a leaf'),
    804: u'GPG_ERR_LDAP_ALIAS_DEREF: ' + _(u'LDAP alias dereferencing problem'),
    815: u'GPG_ERR_LDAP_X_PROXY_AUTH_FAIL: ' + _(u'LDAP proxy authorization failure (X)'),
    816: u'GPG_ERR_LDAP_BAD_AUTH: ' + _(u'Inappropriate LDAP authentication'),
    817: u'GPG_ERR_LDAP_INV_CREDENTIALS: ' + _(u'Invalid LDAP credentials'),
    818: u'GPG_ERR_LDAP_INSUFFICIENT_ACC: ' + _(u'Insufficient access for LDAP'),
    819: u'GPG_ERR_LDAP_BUSY: ' + _(u'LDAP server is busy'),
    820: u'GPG_ERR_LDAP_UNAVAILABLE: ' + _(u'LDAP server is unavailable'),
    821: u'GPG_ERR_LDAP_UNWILL_TO_PERFORM: ' + _(u'LDAP server is unwilling to perform'),
    822: u'GPG_ERR_LDAP_LOOP_DETECT: ' + _(u'Loop detected by LDAP'),
    832: u'GPG_ERR_LDAP_NAMING_VIOLATION: ' + _(u'LDAP naming violation'),
    833: u'GPG_ERR_LDAP_OBJ_CLS_VIOLATION: ' + _(u'LDAP object class violation'),
    834: u'GPG_ERR_LDAP_NOT_ALLOW_NONLEAF: ' + _(u'LDAP operation not allowed on non-leaf'),
    835: u'GPG_ERR_LDAP_NOT_ALLOW_ON_RDN: ' + _(u'LDAP operation not allowed on RDN'),
    836: u'GPG_ERR_LDAP_ALREADY_EXISTS: ' + _(u'Already exists (LDAP)'),
    837: u'GPG_ERR_LDAP_NO_OBJ_CLASS_MODS: ' + _(u'Cannot modify LDAP object class'),
    838: u'GPG_ERR_LDAP_RESULTS_TOO_LARGE: ' + _(u'LDAP results too large'),
    839: u'GPG_ERR_LDAP_AFFECTS_MULT_DSAS: ' + _(u'LDAP operation affects multiple DSAs'),
    844: u'GPG_ERR_LDAP_VLV: ' + _(u'Virtual LDAP list view error'),
    848: u'GPG_ERR_LDAP_OTHER: ' + _(u'Other LDAP error'),
    881: u'GPG_ERR_LDAP_CUP_RESOURCE_LIMIT: ' + _(u'Resources exhausted in LCUP'),
    882: u'GPG_ERR_LDAP_CUP_SEC_VIOLATION: ' + _(u'Security violation in LCUP'),
    883: u'GPG_ERR_LDAP_CUP_INV_DATA: ' + _(u'Invalid data in LCUP'),
    884: u'GPG_ERR_LDAP_CUP_UNSUP_SCHEME: ' + _(u'Unsupported scheme in LCUP'),
    885: u'GPG_ERR_LDAP_CUP_RELOAD: ' + _(u'Reload required in LCUP'),
    886: u'GPG_ERR_LDAP_CANCELLED: ' + _(u'LDAP cancelled'),
    887: u'GPG_ERR_LDAP_NO_SUCH_OPERATION: ' + _(u'No LDAP operation to cancel'),
    888: u'GPG_ERR_LDAP_TOO_LATE: ' + _(u'Too late to cancel LDAP'),
    889: u'GPG_ERR_LDAP_CANNOT_CANCEL: ' + _(u'Cannot cancel LDAP'),
    890: u'GPG_ERR_LDAP_ASSERTION_FAILED: ' + _(u'LDAP assertion failed'),
    891: u'GPG_ERR_LDAP_PROX_AUTH_DENIED: ' + _(u'Proxied authorization denied by LDAP'),
    1500: u'GPG_ERR_SQL_OK: ' + _(u'SQL success'),
    1501: u'GPG_ERR_SQL_ERROR: ' + _(u'SQL error'),
    1502: u'GPG_ERR_SQL_INTERNAL: ' + _(u'Internal logic error in SQL library'),
    1503: u'GPG_ERR_SQL_PERM: ' + _(u'Access permission denied (SQL)'),
    1504: u'GPG_ERR_SQL_ABORT: ' + _(u'SQL abort was requested'),
    1505: u'GPG_ERR_SQL_BUSY: ' + _(u'SQL database file is locked'),
    1506: u'GPG_ERR_SQL_LOCKED: ' + _(u'An SQL table in the database is locked'),
    1507: u'GPG_ERR_SQL_NOMEM: ' + _(u'SQL library ran out of core'),
    1508: u'GPG_ERR_SQL_READONLY: ' + _(u'Attempt to write a readonly SQL database'),
    1509: u'GPG_ERR_SQL_INTERRUPT: ' + _(u'SQL operation terminated by interrupt'),
    1510: u'GPG_ERR_SQL_IOERR: ' + _(u'I/O error during SQL operation'),
    1511: u'GPG_ERR_SQL_CORRUPT: ' + _(u'SQL database disk image is malformed'),
    1512: u'GPG_ERR_SQL_NOTFOUND: ' + _(u'Unknown opcode in SQL file control'),
    1513: u'GPG_ERR_SQL_FULL: ' + _(u'Insertion failed because SQL database is full'),
    1514: u'GPG_ERR_SQL_CANTOPEN: ' + _(u'Unable to open the SQL database file'),
    1515: u'GPG_ERR_SQL_PROTOCOL: ' + _(u'SQL database lock protocol error'),
    1516: u'GPG_ERR_SQL_EMPTY: ' + _(u'(internal SQL code: empty)'),
    1517: u'GPG_ERR_SQL_SCHEMA: ' + _(u'SQL database schema changed'),
    1518: u'GPG_ERR_SQL_TOOBIG: ' + _(u'String or blob exceeds size limit (SQL)'),
    1519: u'GPG_ERR_SQL_CONSTRAINT: ' + _(u'SQL abort due to constraint violation'),
    1520: u'GPG_ERR_SQL_MISMATCH: ' + _(u'Data type mismatch (SQL)'),
    1521: u'GPG_ERR_SQL_MISUSE: ' + _(u'SQL library used incorrectly'),
    1522: u'GPG_ERR_SQL_NOLFS: ' + _(u'SQL library uses unsupported OS features'),
    1523: u'GPG_ERR_SQL_AUTH: ' + _(u'Authorization denied (SQL)'),
    1524: u'GPG_ERR_SQL_FORMAT: ' + _(u'(unused SQL code: format)'),
    1525: u'GPG_ERR_SQL_RANGE: ' + _(u'SQL bind parameter out of range'),
    1526: u'GPG_ERR_SQL_NOTADB: ' + _(u'File opened that is not an SQL database file'),
    1527: u'GPG_ERR_SQL_NOTICE: ' + _(u'Notifications from SQL logger'),
    1528: u'GPG_ERR_SQL_WARNING: ' + _(u'Warnings from SQL logger'),
    1600: u'GPG_ERR_SQL_ROW: ' + _(u'SQL has another row ready'),
    1601: u'GPG_ERR_SQL_DONE: ' + _(u'SQL has finished executing'),
    16381: u'GPG_ERR_MISSING_ERRNO: ' + _(u'System error w/o errno'),
    16382: u'GPG_ERR_UNKNOWN_ERRNO: ' + _(u'Unknown system error'),
    16383: u'GPG_ERR_EOF: ' + _(u'End of file'),
}



# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf-8 -*-
#
# Copyright 2013 Michael Terry <mike@mterry.name>
#
# This file is part of duplicity.
#
# Duplicity is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# Duplicity is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with duplicity; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

u"""Like system tarfile but with caching."""

from __future__ import absolute_import

import tarfile
from duplicity import cached_ops

# Grab all symbols in tarfile, to try to reproduce its API exactly.
# from <> import * wouldn't get everything we want, since tarfile defines
# __all__.  So we do it ourselves.
for sym in dir(tarfile):
    globals()[sym] = getattr(tarfile, sym)

# Now make sure that we cache the grp/pwd ops
grp = pwd = cached_ops
